
# q-expansion of newform 1155.2.q.j, downloaded from the LMFDB on 04 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 1155
weight = 2
poly_data = [576, -144, 1764, 432, 3912, 636, 3192, 78, 1849, -6, 545, 0, 116, 0, 13, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-35949091860021708, 217346382230976, 2786961033508752, 6862352518783002, 6746162402495064, 3806633974242762, 8480124015753019, 1859895297944526, 2650080089579015, 571878154273050, 669193622156012, 122019394096152, 77696950242031, 13752657090600, 6789491580751, 1052323422108], 14439152216125572], [[-77055186943994112, -19883794636599684, -179367573211623312, -73265129489782848, -138507439387519400, -42202482743501496, -85127058980957194, -23849222767852571, -25124629568164570, -7306321595346307, -5624839389651188, -1603980754978492, -638041632625712, -181712154444599, -51169199919132, -14301649856387], 57756608864502288], [[-201692101678562304, -58781998380875148, -469198266636332640, -192345978394216536, -388537668552577944, -111380912333533440, -221460680879859506, -64108087111779609, -64773568346177650, -19631452168946721, -14197743680329516, -4323864688550868, -1603337096909012, -490125834971397, -126349633434392, -38695655880729], 57756608864502288], [[2059437579319728, -19778656130828460, 1336078927516746, -43297315118416032, -4329268812899226, -32352897519714317, 862095899521452, -21002882573039752, 648631954151748, -6302609866825723, 122019394096152, -1406209847412797, 13752657090600, -159510408156428, 1052323422108, -12792299979783], 14439152216125572], [[-742252653594091440, 883236302314058052, -1037558861975933136, 946128387552264840, -1398521493444236688, 828925482722936976, -653839120610453454, 127673957591025751, -177500804440659462, 8727521648512175, -33915512145524532, -8023688177164828, -3702796249791984, -1251007559210333, -255109958373564, -168828305445689], 173269826593506864], [[-52462829473518696, 76529191247901978, -198030788026942752, 104728439114180586, -262437308478170587, 152070164433037630, -183273001907331326, 70167114764718375, -57466576052599481, 18873267045943303, -12400512458261287, 3264807139849362, -1407523770669700, 338914482978299, -106977830653263, 19975964629135], 14439152216125572], [[-101377543855213152, 860520624248728836, -1218182423342993856, 424554925941516288, -1847731356862451136, 528037669132878528, -1179027468897033258, -27573694647219809, -350238806237536674, -38768878189840105, -77601229829857956, -18253659951931876, -8808691255589340, -2405629280400221, -698629967463864, -258092904141113], 173269826593506864], [[60528162307590768, -286835934063442908, 66510081114430224, -582042713433884472, 129172114977081548, -608135213570984528, 139091068533820510, -281057736853614527, 43694399530265914, -77337211822242495, 9874865003637344, -13684469157942820, 1123895107815488, -1434361844437035, 92337059649456, -87236550584191], 57756608864502288], [[-6658481188016640, 148045229166553884, -7654605642864864, -101013909353573904, -185916731235304700, -211678986903367464, -41067439843850070, -256340648170026593, -4107755274512522, -88924381541685649, -978740156433120, -22317346850142772, -103008241920760, -2650177415411957, -6968957788736, -225737113727417], 57756608864502288], [[-178024186249858116, 165408904287912006, -498374134373198160, 495270770085202470, -482139717543000183, 622545597439969320, -384533613431818521, 367019615125222430, -122475758985114984, 108646761180808984, -26822928561277275, 22502710131387130, -3044747544329001, 2511252122975216, -241742927215932, 186689425750364], 43317456648376716], [[-65996624693874240, 29839990267812906, -150079254450818916, -92084784324384192, -216430130655594055, -99047025972707124, -76348058708277002, -100656361361038757, -17630576282799791, -33484876351728925, -2728158307995631, -8204363113081372, -261044731651852, -963194108937821, -10564133477445, -81351716361131], 14439152216125572], [[-1760173007772960, 76747001984329356, 75046546240713072, -81764844659264784, 38237647479215844, -133398424885334832, 67609532445102486, -110860078182754393, 24110187693399882, -35210480879697209, 5645835340684176, -8158834782198884, 652061184764964, -940644573385813, 54691716865524, -76696915955089], 13328448199500528], [[-97124270614459092, -50104396041027642, -386102852581251888, -629664565526740308, -521970311356316391, -632159901101034540, -179057709111651663, -460063657061418334, -41336565925973862, -144687727864103072, -8054719626579699, -32924616806987990, -875507885770671, -3777842455006816, -58973541029706, -304197521667406], 43317456648376716], [[-5234701676774292, -24940349224618374, -28536809620892562, -94523827977625368, -44513257975024251, -84555593059895859, -12675647522015985, -57685597483886833, -2451126057099780, -17789053367396456, -479180234420373, -4000783357823993, -51489876770523, -456723671279011, -3305487068346, -36593349740146], 3332112049875132]]

hecke_ring_character_values = [[386, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [232, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [661, [-1, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [211, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -2, 0, 0, 0, -2, 0, -1, 0, -1, -1, 0, 1, 0, 0, 0], [0, 0, 0, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 1, 2, 0, 1, 2, 0, -1, 0, 0, -1, -1], [1, 0, -1, 1, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0], [-1, -1, -1, 0, 0, -1, 0, 1, 0, -2, -2, 0, -1, 0, 0, 0], [0, -1, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0], [1, 0, -1, 1, 1, 1, 1, 1, 2, 2, 0, 1, 0, 0, -1, 0], [1, -1, 1, 0, 0, -1, 2, 1, 0, 0, 0, -2, -1, -2, 2, -2], [2, 2, 0, 0, 0, 2, 0, -1, 0, 1, 1, 0, 1, 0, 0, 0], [1, 0, 3, 1, -3, 2, 1, 0, 2, 1, 0, 1, 0, 0, 0, -1], [0, 0, 0, -1, 1, 0, -1, 0, -1, 0, 3, 2, 0, 1, 1, 0], [0, 1, 0, 1, -2, 0, 1, 0, 0, 0, 1, -1, -1, -1, 0, 0], [-4, 0, 0, -4, 0, 0, 0, 0, 0, -2, 0, 0, 0, 0, 2, -2], [0, 1, 0, 1, -1, 0, 2, 0, -1, 0, 0, 1, 1, 0, 3, 0], [-4, -2, -1, 0, 0, -2, -2, -1, 1, 0, 0, 0, 1, 1, 0, 1], [0, -1, 0, 2, -2, 0, 2, 0, -1, 0, -1, 0, -1, -1, 2, 0], [0, 0, 0, 0, 0, 1, 0, 2, 1, 2, 0, 1, 0, 0, -1, 1], [3, 0, 1, 0, 0, 0, -2, 2, 1, 3, 3, 2, -2, 1, -2, 1], [0, 0, 1, 0, -1, 2, 0, -1, 1, 0, 0, 1, 0, 0, 1, -1], [7, -2, -1, 0, 0, -2, -1, 1, 0, 2, 2, 2, -1, 1, -2, 1], [0, 0, 0, -1, 1, 0, -1, 0, 3, 0, -1, -2, -2, 1, -3, 0], [-4, 0, 2, -4, -2, 1, -2, 0, 1, 2, 0, 3, 0, 0, -1, 3], [0, 0, -2, 0, 2, 0, -2, -2, 0, -2, 0, 2, 0, 0, 2, 0], [0, -1, 0, -3, 1, 0, -2, 0, 1, 0, -2, 1, 1, 2, -1, 0], [0, 1, -2, 0, 0, 1, 4, -1, -1, -1, -1, -1, 1, -3, 1, -3], [6, 5, 0, 0, 0, 5, 1, 3, 0, 1, 1, -1, -3, -1, 1, -1], [-9, 0, -1, -9, 1, 0, -3, 0, -2, -1, 0, 1, 0, 0, 0, 3], [0, 6, 0, 1, 1, 0, 1, 0, -3, 0, 3, 0, 0, -3, 1, 0], [5, 1, -3, 0, 0, 1, 9, 1, -5, 0, 0, -4, -1, -4, 4, -4], [-3, 0, 1, -3, -1, -4, 1, 0, 0, -1, 0, -1, 0, 0, 0, -1], [0, 4, 0, 1, 1, 0, 0, 0, 1, 0, 2, 0, -1, 1, 0, 0], [0, -4, 0, 7, 1, 0, -2, 0, 1, 0, -2, 2, 1, 3, 0, 0], [-7, 0, 1, -7, -1, 0, -1, -3, -1, 0, 0, 0, 0, 0, 2, -1], [-1, 1, -3, 0, 0, 1, -1, 0, 1, -1, -1, -1, 0, 0, 1, 0], [-2, 0, 0, -2, 0, -3, 0, 0, -2, 0, 0, -2, 0, 0, -3, 3], [0, 3, 0, -7, -2, 0, 1, 0, 0, 0, -3, -1, -1, -1, 0, 0], [-1, -3, 0, 0, 0, -3, 0, -1, -1, 1, 1, -1, 1, 1, 1, 1], [9, 0, 0, 9, 0, 3, 2, 1, 0, 3, 0, -2, 0, 0, 1, -3], [0, 0, 0, 2, -2, 0, 0, 0, -3, 0, -2, 1, 0, -2, 1, 0], [3, 2, 1, 0, 0, 2, -2, 0, 1, 5, 5, 2, 0, 1, -2, 1], [0, -2, 0, 11, -2, 0, 3, 0, -1, 0, -3, 1, 1, 0, 4, 0], [-1, 0, -1, 0, 0, 0, 1, -3, 0, -4, -4, -2, 3, -1, 2, -1], [3, 2, 5, 0, 0, 2, 1, 3, 0, 2, 2, 0, -3, -1, 0, -1], [0, -6, 0, 1, -1, 0, 2, 0, 0, 0, -1, -1, 2, -1, 1, 0], [5, 0, 0, 5, 0, -3, -3, -1, -4, -3, 0, -1, 0, 0, 0, 3], [3, 0, 5, 3, -5, 1, 2, -2, -1, 1, 0, -3, 0, 0, -2, 0], [-10, -6, 0, 0, 0, -6, 4, -2, -4, -4, -4, -4, 2, 0, 4, 0], [0, -2, 0, 1, 3, 0, -2, 0, -1, 0, 2, 2, -3, 1, 0, 0], [11, -3, -1, 0, 0, -3, -3, -2, 3, -3, -3, -1, 2, 0, 1, 0], [-3, 0, -1, -3, 1, -3, 0, -1, 0, -2, 0, 0, 0, 0, -4, 4], [0, 0, 0, -1, -1, 0, -2, 0, 0, 0, -3, 3, -2, 3, 1, 0], [0, -1, 0, -1, 3, 0, 1, 0, 0, 0, 1, -2, -2, -2, -1, 0], [-9, 0, 1, -9, -1, 2, 1, 1, 3, 0, 0, 2, 0, 0, 2, -3], [0, 0, 0, 0, 2, 0, -2, 0, -2, 0, 1, 0, -1, -2, -2, 0], [1, 6, -1, 0, 0, 6, -4, 2, 3, 1, 1, 3, -2, 1, -3, 1], [0, 4, 0, 2, 2, 0, -1, 0, -5, 0, 3, 3, -1, -2, 2, 0], [-5, -2, -3, 0, 0, -2, 0, -4, -1, -7, -7, -4, 4, 1, 4, 1], [0, -1, -2, 0, 0, -1, 0, 0, 1, 0, 0, -3, 0, -1, 3, -1], [0, 0, 0, 0, 1, 0, 2, 0, -4, 0, 2, 1, 1, -3, 3, 0], [-1, 0, 5, -1, -5, -3, -1, 1, -2, 0, 0, -1, 0, 0, 5, -4], [1, 0, -1, 1, 1, -3, 0, 3, 2, 2, 0, 2, 0, 0, 2, -2], [9, 0, 0, 9, 0, -3, -1, -1, 2, -1, 0, 3, 0, 0, -2, 3], [8, 3, 2, 0, 0, 3, 3, -3, -4, 1, 1, 0, 3, 1, 0, 1], [0, -7, 0, 4, 0, 0, 1, 0, 4, 0, 0, -1, 2, 3, 0, 0], [9, -10, -5, 0, 0, -10, -5, -3, 2, -6, -6, 0, 3, 3, 0, 3], [0, -3, 0, -3, -1, 0, -2, 0, -2, 0, 0, 6, 3, 4, 4, 0], [11, 0, -1, 11, 1, -8, 1, -2, -2, -1, 0, -3, 0, 0, -2, 1], [0, -1, 0, 4, 2, 0, -8, 0, 2, 0, 4, 5, 2, 7, -3, 0], [-10, 0, 4, -10, -4, -3, -5, 0, -4, -2, 0, 1, 0, 0, 4, 1], [1, -2, 4, 0, 0, -2, -1, 1, 1, -1, -1, -3, -1, 0, 3, 0], [-2, 0, 6, -2, -6, -1, -1, -1, -2, -1, 0, -1, 0, 0, 0, 1], [0, -3, 0, 3, 0, 0, -7, 0, 2, 0, 1, 5, -1, 7, -2, 0], [0, 0, 2, 0, -2, 3, 2, -2, 1, 4, 0, -1, 0, 0, -1, -1], [7, 0, 0, 7, 0, -9, 0, 1, 0, -3, 0, 0, 0, 0, 1, -1], [0, 1, 0, 3, 5, 0, -2, 0, -1, 0, 2, -1, -1, -2, -3, 0], [12, 4, -1, 0, 0, 4, 0, -1, -1, 8, 8, 0, 1, 1, 0, 1], [6, 0, -6, 0, 0, 0, -2, 3, 2, 3, 3, 3, -3, 0, -3, 0], [0, 8, 0, 1, 5, 0, -1, 0, 3, 0, 3, -2, -2, 1, -3, 0], [-6, 3, 0, 0, 0, 3, 4, 0, 1, -4, -4, -2, 0, -5, 2, -5], [4, 0, -2, 4, 2, -4, -2, 2, -4, 4, 0, -2, 0, 0, 0, 2], [2, 0, 4, 2, -4, 0, -6, 0, 0, -4, 0, 6, 0, 0, 4, 2], [-8, -6, 1, 0, 0, -6, -6, 1, 3, 2, 2, 2, -1, 3, -2, 3], [-4, 0, 2, -4, -2, -7, 5, -2, -4, 2, 0, -9, 0, 0, -4, -1], [13, 5, 3, 0, 0, 5, 0, 1, 2, 6, 6, 2, -1, -2, -2, -2], [12, 1, 0, 0, 0, 1, -4, 0, -1, 4, 4, 6, 0, 5, -6, 5], [-9, 0, 1, -9, -1, -3, -6, 3, -2, -4, 0, 4, 0, 0, 8, -2], [0, -7, 0, 0, -4, 0, 1, 0, 3, 0, -1, -4, -1, -1, -3, 0], [0, 5, 0, -11, 1, 0, 2, 0, -1, 0, 8, -1, -1, -2, 1, 0], [-3, 3, 3, 0, 0, 3, -6, -1, 4, 2, 2, 2, 1, 2, -2, 2], [5, 0, -2, 5, 2, 8, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0], [5, 2, -7, 0, 0, 2, 4, -2, -1, -3, -3, -6, 2, -3, 6, -3], [13, 0, 4, 13, -4, 3, 6, 3, 4, 3, 0, -2, 0, 0, 1, -7], [0, 0, 0, -8, 1, 0, -4, 0, -4, 0, 0, 5, 5, 1, 1, 0], [-8, 0, 0, -8, 0, -1, 1, 0, 2, 0, 0, 1, 0, 0, 0, -1], [8, 0, 6, 8, -6, 5, 4, 0, 5, -2, 0, 1, 0, 0, -3, -1], [4, 1, -4, 0, 0, 1, -4, 3, 3, 3, 3, 2, -3, 1, -2, 1], [0, -7, 0, -1, 3, 0, 1, 0, 8, 0, -3, -6, 0, 2, -5, 0], [0, -1, 0, 14, 2, 0, -1, 0, 4, 0, 0, -1, -4, 3, -2, 0], [-3, 0, -5, -3, 5, 2, -1, 0, -2, -3, 0, -1, 0, 0, -2, 3], [0, -7, 0, -5, 1, 0, 2, 0, 1, 0, 2, -1, 1, 0, 1, 0], [0, -1, 0, -4, -4, 0, 2, 0, -10, 0, 2, 3, 2, -7, 5, 0], [13, 11, -5, 0, 0, 11, 0, 5, 0, 4, 4, 2, -5, 0, -2, 0], [0, 0, -2, 0, 2, -7, -2, 2, 0, 0, 0, 2, 0, 0, 1, 1], [0, 2, 0, -10, -1, 0, 0, 0, 2, 0, 0, -3, 1, -1, -3, 0], [9, 5, -5, 0, 0, 5, -5, 3, 3, 4, 4, 8, -3, 2, -8, 2], [-10, 0, 0, -10, 0, -4, 2, -3, 0, -1, 0, -2, 0, 0, 0, -2], [0, -6, 0, 8, 2, 0, -9, 0, 3, 0, 0, 5, 4, 8, -4, 0], [-1, 6, 3, 0, 0, 6, 0, 0, -1, -3, -3, -3, 0, 1, 3, 1], [0, -8, 0, 2, 0, 0, 3, 0, -1, 0, 1, -1, 1, -2, 2, 0], [3, 0, -2, 0, 0, 0, -12, 3, 6, 1, 1, 9, -3, 6, -9, 6], [0, 5, 0, -7, -7, 0, -7, 0, -4, 0, 1, 6, 0, 2, -1, 0], [12, 1, 0, 0, 0, 1, -6, 2, 3, 6, 6, 4, -2, 3, -4, 3], [0, 9, 0, -11, 3, 0, 2, 0, -2, 0, 6, 0, -3, -2, 2, 0], [7, 0, 3, 7, -3, 1, 0, -5, -2, 2, 0, -2, 0, 0, -6, 6], [-11, -9, 9, 0, 0, -9, -4, -5, 2, -6, -6, 0, 5, 2, 0, 2], [0, 6, 0, -4, 8, 0, 2, 0, 1, 0, 4, -1, -2, 0, 1, 0], [12, -5, 0, 0, 0, -5, -8, 4, 3, -4, -4, 7, -4, 5, -7, 5], [3, 0, -7, 3, 7, -3, -2, -4, 1, -1, 0, 3, 0, 0, -2, 4], [0, 6, 0, -14, 2, 0, -2, 0, -6, 0, 12, 4, 2, -2, 2, 0], [-4, 0, 2, -4, -2, 0, 7, 1, 1, 1, 0, -6, 0, 0, -7, 0], [-14, 3, -2, 0, 0, 3, 0, 3, 5, 3, 3, 1, -3, -5, -1, -5], [-13, 0, -2, -13, 2, 7, -4, -2, -1, -4, 0, 3, 0, 0, 5, -1], [3, 0, 3, 3, -3, -7, 0, 0, -3, 3, 0, -3, 0, 0, 0, 0], [-3, -9, 7, 0, 0, -9, 3, -5, -3, -4, -4, -4, 5, 0, 4, 0], [-8, 0, 0, -8, 0, 0, 1, -1, -1, 7, 0, -2, 0, 0, -1, 0], [0, -5, 0, -2, -4, 0, 4, 0, 10, 0, -2, -9, 0, 1, -5, 0], [-14, -11, -2, 0, 0, -11, 1, -6, -2, -6, -6, -1, 6, 1, 1, 1], [-1, 0, 4, -1, -4, 15, 5, 6, 3, 2, 0, -2, 0, 0, 4, -9], [9, 8, 3, 0, 0, 8, -1, -3, -2, -2, -2, 2, 3, 3, -2, 3], [-27, 0, -3, -27, 3, 1, 0, -5, -2, -8, 0, -2, 0, 0, -2, 2], [2, -3, 0, 0, 0, -3, 12, -4, -9, -4, -4, -8, 4, -3, 8, -3], [0, 5, 0, -14, 4, 0, -3, 0, 3, 0, -1, -2, -1, 1, -5, 0], [0, -6, 0, 12, 4, 0, 4, 0, 3, 0, -15, -5, -1, -2, -1, 0], [5, 8, 5, 0, 0, 8, -16, -4, 5, -1, -1, 11, 4, 11, -11, 11], [0, -7, 0, -7, -1, 0, 2, 0, 0, 0, 0, 0, 3, 0, 2, 0], [12, 10, 2, 0, 0, 10, -6, 6, 8, 6, 6, 4, -6, -2, -4, -2], [12, 0, -8, 12, 8, -12, -6, 0, -2, -4, 0, 4, 0, 0, 6, 0], [0, 2, 0, 24, 0, 0, 0, 0, 2, 0, -4, -4, 0, -2, -4, 0], [-7, -9, 3, 0, 0, -9, -1, 0, 1, -3, -3, -3, 0, 0, 3, 0], [0, -6, 0, -5, -4, 0, 2, 0, 2, 0, -6, -2, -2, 0, 0, 0], [19, 1, 3, 0, 0, 1, -3, 2, -1, 1, 1, 7, -2, 4, -7, 4], [8, -3, 2, 0, 0, -3, 5, -3, -6, 1, 1, 5, 3, 1, -5, 1], [0, -10, 0, -1, -11, 0, 4, 0, 4, 0, -1, -5, 0, -1, -1, 0], [-4, 0, -8, -4, 8, -10, -4, 1, 1, -3, 0, 5, 0, 0, 2, 2], [-11, 0, 1, -11, -1, -1, 2, 7, 0, 4, 0, -2, 0, 0, -4, 2], [2, 0, -8, 2, 8, -1, 2, 3, 3, -7, 0, 1, 0, 0, -1, -1], [-5, 1, -2, 0, 0, 1, -5, -3, 4, -1, -1, 1, 3, 1, -1, 1], [7, -11, -7, 0, 0, -11, 1, -3, 1, 0, 0, -2, 3, -2, 2, -2], [0, 0, 8, 0, -8, -7, 6, -2, -2, 4, 0, -8, 0, 0, -9, 3], [0, 5, 0, 19, 3, 0, 0, 0, -1, 0, 0, 1, -3, 0, 1, 0], [-9, 9, -6, 0, 0, 9, 13, -1, -6, 7, 7, -7, 1, -7, 7, -7], [-1, 0, 1, -1, -1, 5, -1, -3, 2, -6, 0, 3, 0, 0, -1, 2], [6, 0, 0, 6, 0, -8, 6, 0, 4, 8, 0, -2, 0, 0, -6, 0], [-4, 7, -4, 0, 0, 7, 0, 0, -1, 0, 0, 5, 0, 1, -5, 1], [0, 5, 0, 0, -10, 0, 5, 0, -3, 0, 3, 0, 1, -3, 5, 0], [12, 0, -6, 12, 6, -6, -6, -4, 2, 2, 0, 8, 0, 0, 6, 0], [3, -7, 5, 0, 0, -7, 5, 2, -1, 1, 1, -9, -2, -4, 9, -4], [12, 7, -2, 0, 0, 7, 3, 5, -2, -7, -7, -2, -5, -1, 2, -1], [-7, 0, -2, -7, 2, -3, -6, -3, -2, 1, 0, 4, 0, 0, -3, 9], [0, -20, 0, 2, -2, 0, -4, 0, 2, 0, -6, 2, 0, 4, -2, 0], [0, 3, 0, -5, -5, 0, -4, 0, -4, 0, -4, 4, -1, 0, 0, 0], [0, -4, 0, -10, -4, 0, -2, 0, 3, 0, 4, -1, -2, 2, -3, 0], [0, -5, 0, 6, 6, 0, 1, 0, -1, 0, 2, -4, -4, -5, -3, 0], [-9, 1, -5, 0, 0, 1, -3, -3, 3, -4, -4, -2, 3, 0, 2, 0], [1, 0, 7, 1, -7, -7, 0, -1, -2, -2, 0, -2, 0, 0, 10, -10], [0, 9, 0, -3, -5, 0, -6, 0, -4, 0, 2, 4, -3, 0, -2, 0], [-21, 0, 2, 0, 0, 0, 8, -1, -6, -1, -1, -5, 1, -2, 5, -2], [-10, 0, 0, -10, 0, 1, 3, -3, 2, 3, 0, -1, 0, 0, 6, -9], [0, 8, 0, 12, 6, 0, 1, 0, -4, 0, 0, 2, 0, -2, 3, 0], [0, -10, 0, -6, -8, 0, -2, 0, 5, 0, -4, -1, 2, 4, -3, 0], [11, -5, -2, 0, 0, -5, -1, -5, 2, -3, -3, -1, 5, -1, 1, -1], [2, 3, 4, 0, 0, 3, -2, 4, 5, 14, 14, 10, -4, -3, -10, -3], [0, -2, 0, 16, 5, 0, 4, 0, 6, 0, -8, -5, -3, 1, -1, 0], [-14, 2, 8, 0, 0, 2, -3, -1, -1, -7, -7, 1, 1, 4, -1, 4], [13, 0, -3, 13, 3, 3, 1, -3, 4, 4, 0, 3, 0, 0, -3, 2], [-7, 0, -1, -7, 1, 1, 7, -1, -4, 8, 0, -11, 0, 0, -9, 2], [7, -18, 3, 0, 0, -18, 0, -6, -1, -11, -11, -7, 6, 1, 7, 1], [-6, -3, 0, 0, 0, -3, 6, -2, -7, 6, 6, 2, 2, 1, -2, 1], [7, 0, 3, 7, -3, 4, 8, -2, 7, 3, 0, -1, 0, 0, 1, -9], [0, -2, 0, -2, 0, 0, -2, 0, 0, 0, -2, 0, -2, 0, -2, 0], [0, 7, 0, 9, -8, 0, 5, 0, -4, 0, -3, 3, 3, -1, 8, 0], [0, -4, 0, 8, -6, 0, -4, 0, -1, 0, -11, -1, -1, -2, -5, 0], [0, -1, 0, 3, -9, 0, 4, 0, 1, 0, -6, -5, 3, -4, -1, 0], [25, 0, 5, 25, -5, 5, -1, -1, -2, 10, 0, -1, 0, 0, 1, 0], [0, 12, 0, -3, 5, 0, -7, 0, -3, 0, 11, -2, -4, -5, -9, 0], [-7, 0, 1, -7, -1, -11, -3, -5, -10, -14, 0, -7, 0, 0, 3, 0], [-4, -11, 6, 0, 0, -11, -17, -2, 6, -8, -8, 5, 2, 11, -5, 11], [-1, 0, -10, -1, 10, 5, 12, -2, 7, 2, 0, -5, 0, 0, -9, -3], [-3, 0, 6, -3, -6, 1, -2, 3, -2, 1, 0, 0, 0, 0, -7, 9], [0, -18, 0, 13, -11, 0, 10, 0, 4, 0, -13, -5, 2, -1, 5, 0], [0, 6, 0, -12, 2, 0, 8, 0, -10, 0, 4, 0, -2, -10, 8, 0], [0, -9, 0, 23, 9, 0, -2, 0, -1, 0, 4, 3, -1, 2, 1, 0], [-14, 0, 2, -14, -2, -10, -8, -2, -2, -12, 0, 6, 0, 0, 0, 8], [8, 13, -4, 0, 0, 13, -1, 4, 0, 2, 2, 5, -4, 1, -5, 1], [-9, 0, -3, -9, 3, 4, 0, 6, 3, 3, 0, 3, 0, 0, 3, -3], [0, 3, 0, -13, -7, 0, 8, 0, 4, 0, 2, -8, -1, -4, 0, 0], [-14, -3, -4, 0, 0, -3, -4, -4, -1, -8, -8, 4, 4, 5, -4, 5], [-3, 0, -1, -3, 1, -2, -5, 1, -3, 6, 0, 2, 0, 0, -4, 9], [0, 4, 0, 1, -1, 0, 0, 0, -11, 0, 10, 8, -1, -3, 8, 0], [16, 20, -4, 0, 0, 20, -4, 0, 4, 0, 0, 4, 0, 0, -4, 0], [0, 10, 0, -7, -11, 0, 1, 0, -7, 0, 7, 4, 0, -3, 5, 0], [2, 0, -14, 2, 14, -10, -6, -3, 1, -9, 0, 7, 0, 0, 2, 4], [-3, 0, -3, -3, 3, -6, -8, -2, -9, -11, 0, -1, 0, 0, 11, -3], [-6, -4, -4, 0, 0, -4, -6, 0, 0, 2, 2, 2, 0, 6, -2, 6], [0, 5, 0, -1, 4, 0, -7, 0, -6, 0, 11, 7, -1, 1, 0, 0], [-6, 0, 6, -6, -6, -10, 7, 5, 7, 7, 0, 0, 0, 0, -3, -4], [-12, 0, 7, 0, 0, 0, 0, 7, 1, 10, 10, 6, -7, -1, -6, -1], [-2, -12, 0, 0, 0, -12, 4, -8, 2, -4, -4, -4, 8, -6, 4, -6], [19, 0, 9, 19, -9, 2, -3, 0, 2, -1, 0, 5, 0, 0, 0, 3], [0, -7, 0, -1, 3, 0, -2, 0, -4, 0, 0, 2, 1, -2, 0, 0], [-12, 0, -2, -12, 2, -7, -12, -3, -8, -5, 0, 4, 0, 0, 9, 3], [0, -7, 0, 22, 10, 0, -8, 0, 4, 0, -11, 3, 9, 7, -5, 0], [0, -8, 0, 8, -2, 0, 2, 0, 6, 0, -8, -8, -6, -2, -6, 0], [-3, 0, 7, -3, -7, 14, -1, 0, -2, 9, 0, -1, 0, 0, -6, 7], [2, 2, -6, 0, 0, 2, -8, 4, 4, -2, -2, 6, -4, 4, -6, 4], [2, 0, 12, 2, -12, -9, 0, 0, -3, -2, 0, -3, 0, 0, -1, 1], [-3, -11, 7, 0, 0, -11, -13, -3, 9, 0, 0, 0, 3, 4, 0, 4], [14, 0, -1, 14, 1, 0, -8, 5, 3, -4, 0, 11, 0, 0, 7, 1], [12, 0, -6, 12, 6, 8, 4, 2, 6, 8, 0, 2, 0, 0, -6, 2], [27, 1, -11, 0, 0, 1, 1, 0, -5, -1, -1, -1, 0, 4, 1, 4], [5, 2, 7, 0, 0, 2, 3, -3, -2, 14, 14, 0, 3, -1, 0, -1], [7, 0, 7, 7, -7, 16, -7, 4, -2, 9, 0, 5, 0, 0, 4, 3], [0, -16, 0, -8, -9, 0, -6, 0, 6, 0, -2, 1, 7, 7, -5, 0], [-14, 0, -2, -14, 2, 4, -3, -6, -2, -4, 0, 1, 0, 0, 5, -2], [-1, 0, 1, -1, -1, -6, 5, 2, 2, -1, 0, -3, 0, 0, -8, 3], [0, -7, 0, 20, -2, 0, 0, 0, 2, 0, -8, 3, -6, 5, 3, 0], [0, 6, 0, 10, 6, 0, -2, 0, 2, 0, 8, -2, -2, 0, -4, 0], [-10, 3, -4, 0, 0, 3, -14, -4, 7, 0, 0, 2, 4, 7, -2, 7], [0, -1, 0, 11, -1, 0, -6, 0, 0, 0, 10, 2, 1, 2, -4, 0], [5, -13, 11, 0, 0, -13, 1, 5, 5, -6, -6, 0, -5, -6, 0, -6], [0, 8, 0, -22, 4, 0, -2, 0, -6, 0, 0, 8, 2, 2, 6, 0], [11, 0, -8, 11, 8, 5, -3, 5, -4, 3, 0, -1, 0, 0, 10, -7], [0, 0, 2, 0, -2, 3, -2, -6, 0, -4, 0, 2, 0, 0, -1, 3], [-6, 8, 7, 0, 0, 8, -4, 1, 5, -2, -2, 2, -1, -1, -2, -1], [5, -29, 0, 0, 0, -29, 1, -9, -6, -7, -7, -1, 9, 5, 1, 5], [0, -6, 0, 9, -9, 0, -1, 0, 7, 0, -1, 2, 2, 9, 1, 0], [14, 0, -6, 14, 6, 15, 10, 2, 7, 0, 0, -3, 0, 0, -3, -7], [0, -13, 0, -12, -2, 0, 4, 0, 4, 0, 4, -5, -2, -1, -1, 0], [-13, 0, 6, -13, -6, 18, 1, 5, -3, 1, 0, -4, 0, 0, -1, 0], [8, -7, 0, 0, 0, -7, 11, -2, -8, 4, 4, -1, 2, -3, 1, -3], [17, 0, -7, 17, 7, 13, 8, -3, 4, 8, 0, -4, 0, 0, -8, 0], [11, 11, -5, 0, 0, 11, 1, 7, 3, 12, 12, 6, -7, -4, -6, -4], [0, 15, 0, 7, -3, 0, -1, 0, 10, 0, -1, -2, -2, 8, -3, 0], [0, 4, 0, -8, 2, 0, -2, 0, 8, 0, -6, -2, 8, 6, -4, 0], [6, -4, 0, 0, 0, -4, 12, 6, -6, 4, 4, -2, -6, -6, 2, -6], [24, 7, 12, 0, 0, 7, 5, 9, 2, 13, 13, 0, -9, -7, 0, -7], [-1, 0, 5, -1, -5, 22, 7, -2, 4, -1, 0, -3, 0, 0, -2, -5], [0, -12, 0, 3, -1, 0, 7, 0, -1, 0, -7, -4, 4, -5, 3, 0], [-13, -9, 2, 0, 0, -9, -5, 2, 2, -2, -2, -2, -2, 3, 2, 3], [0, -13, 0, -15, -7, 0, -3, 0, -2, 0, 5, 4, 2, 2, 1, 0], [15, 0, 3, 15, -3, -2, -1, 2, -4, 3, 0, -3, 0, 0, 6, -5], [0, 1, 0, 13, -8, 0, 8, 0, 5, 0, -4, -12, -2, -7, -4, 0], [0, -8, 0, -12, 8, 0, 4, 0, 5, 0, 0, -9, -4, -4, -5, 0], [-8, -4, -8, 0, 0, -4, 14, 4, -4, -12, -12, -12, -4, -10, 12, -10], [-14, 0, 4, -14, -4, 5, 4, 2, -4, -8, 0, -8, 0, 0, -1, -3], [0, 3, 0, 14, 12, 0, 4, 0, 7, 0, -5, -6, -5, 1, -2, 0], [-19, -4, -5, 0, 0, -4, 24, 0, -19, 3, 3, -12, 0, -5, 12, -5], [0, -9, 0, 1, 5, 0, 8, 0, 3, 0, -12, 1, 5, 4, 9, 0], [4, -15, 8, 0, 0, -15, -19, -3, 8, -15, -15, 4, 3, 11, -4, 11], [0, 3, 0, -1, -1, 0, 4, 0, -4, 0, -6, -6, -3, -10, -2, 0], [19, 0, 2, 19, -2, -4, -2, 4, 8, -4, 0, 10, 0, 0, -2, 4], [-16, 14, 3, 0, 0, 14, 10, 1, 1, 0, 0, -4, -1, -11, 4, -11], [-20, -6, -7, 0, 0, -6, 16, -3, -13, -10, -10, -10, 3, -3, 10, -3], [-2, -25, -6, 0, 0, -25, -4, 1, 3, -1, -1, -1, -1, 1, 1, 1], [0, -1, 0, 4, -6, 0, 1, 0, -6, 0, 4, 1, -6, -5, 2, 0], [-1, 0, -18, -1, 18, -7, -1, 4, -1, -4, 0, 0, 0, 0, 0, 1], [0, 8, 0, -6, 4, 0, -2, 0, -4, 0, 10, 2, -2, -2, 0, 0], [0, -13, 0, 12, -12, 0, 6, 0, 6, 0, -14, -3, 2, 3, 3, 0], [-9, 0, -1, -9, 1, -9, -17, -9, -18, -20, 0, -1, 0, 0, 13, 4], [4, -1, -4, 0, 0, -1, 27, 2, -16, 6, 6, -13, -2, -11, 13, -11], [-16, 0, -2, -16, 2, -14, 2, -6, 4, -8, 0, 2, 0, 0, -10, 8], [-9, 0, -1, -9, 1, -17, 6, 1, 2, 0, 0, -4, 0, 0, 6, -12], [0, 9, 0, -4, 8, 0, -14, 0, -2, 0, 6, 13, -4, 11, -1, 0], [0, 0, 8, 0, -8, 1, -14, 4, -5, 2, 0, 9, 0, 0, 7, 7], [-21, 0, 5, -21, -5, 10, -1, 2, 0, -1, 0, 1, 0, 0, 2, -1], [0, -7, 0, -4, 2, 0, 3, 0, -2, 0, -6, -3, 12, -5, 0, 0], [0, 6, 0, 5, 6, 0, 2, 0, 8, 0, -2, -8, 6, 0, -6, 0], [-10, -21, -2, 0, 0, -21, -11, 2, 8, -6, -6, 7, -2, 3, -7, 3], [6, -1, -12, 0, 0, -1, 12, 6, -3, -2, -2, -12, -6, -9, 12, -9], [-44, 0, -2, -44, 2, 0, -5, 1, -2, -3, 0, 3, 0, 0, 1, 4], [22, 0, 10, 22, -10, 2, 4, -6, 4, -4, 0, 0, 0, 0, 0, -4], [0, 15, 0, 2, 4, 0, -8, 0, 8, 0, 0, 3, 4, 11, -5, 0], [-6, 9, -2, 0, 0, 9, -7, 0, 12, -4, -4, 3, 0, -5, -3, -5], [0, 7, 0, -23, -8, 0, -3, 0, -5, 0, -3, 6, -9, 1, 3, 0], [25, -2, -1, 0, 0, -2, -4, 2, 3, 1, 1, -3, -2, 1, 3, 1], [0, -1, 0, -21, 10, 0, -5, 0, 4, 0, 11, 3, -1, 7, -2, 0], [0, 7, 0, -3, -7, 0, 4, 0, 0, 0, 0, 2, -3, 2, 6, 0], [5, 0, 7, 5, -7, 4, -2, 6, -3, 1, 0, -1, 0, 0, 1, 1], [1, -11, -7, 0, 0, -11, 14, 5, -2, -4, -4, -10, -5, -12, 10, -12], [-12, 19, -2, 0, 0, 19, 4, 2, 3, 2, 2, -7, -2, -7, 7, -7], [0, -1, 0, -1, 11, 0, -10, 0, -4, 0, 16, 10, -1, 6, 0, 0], [-5, 0, 16, -5, -16, -8, -2, -8, -4, -10, 0, -2, 0, 0, 4, -2], [9, -12, 1, 0, 0, -12, 4, 2, -1, 13, 13, 7, -2, -3, -7, -3], [-9, 0, -7, -9, 7, -6, -9, -6, -10, 1, 0, -1, 0, 0, 4, 5], [-4, -8, -6, 0, 0, -8, 6, -7, -6, -7, -7, -8, 7, 0, 8, 0], [-26, 0, -2, -26, 2, -15, -14, -1, -15, -15, 0, -1, 0, 0, 5, 9], [0, 0, 2, 0, -2, -11, 0, -2, 0, -4, 0, 0, 0, 0, -5, 5], [0, 12, 0, 16, 0, 0, 10, 0, -6, 0, 2, 0, 0, -6, 10, 0]]
